#
# spec file for package python-rtslib
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-rtslib
Version:        2.2
Release:        19.3.1
Summary:        API for Linux kernel SCSI target (aka LIO)
License:        Apache-2.0
Group:          Development/Languages/Python
%define oname rtslib
Url:            https://github.com/Datera/rtslib
Source:         %{oname}-%{version}.tar.bz2
Patch0:         %{oname}-git-update.patch
Patch1:         %{oname}-set-git-version-for-sle12.patch
Patch2:         %{oname}-add-prot-info-attributes.patch
Patch3:         %{oname}-add-iblock-backstore-policy.patch
Patch4:         %{oname}-mount-configfs-fix.patch
Patch5:         %{oname}-fix_support_for_disabled_tpgs.patch
Patch6:         %{oname}-fb-rbd-support.patch
Patch7:         %{oname}-load-rbd-mod-on-startup.patch
Patch8:         %{oname}-fix-64bit-SIOCGIFCONF-unmarshalling.patch
Patch9:         %{oname}-add-qla2xxx_wwn-wwn-type
Patch10:        %{oname}-fix-iqn-wwn.patch
Patch11:        %{oname}-add-nvme-support.patch
Patch12:        0001-Add-support-for-xen-scsiback.patch
Patch13:        %{oname}-validate-fc_wwn.patch
Patch14:        %{oname}-disallow-upper-case-iqn-names.patch
Patch15:        %{oname}-fix-parse-error-with-new-pyparsing.patch
Requires:       python-configobj
Requires:       python-ipaddr
Requires:       python-netifaces
Requires:       python-pyparsing
BuildRequires:  python-configobj
BuildRequires:  python-devel
BuildRequires:  python-ipaddr
BuildRequires:  python-netifaces
BuildRequires:  python-pyparsing
BuildRequires:  python-setuptools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# explicit Provides advertising RBD support
Provides:       %{name}-rbd = %{version}
Obsoletes:      %{name}-rbd < %{version}
Provides:       %{name}-doc = %{version}
Obsoletes:      %{name}-doc < %{version}
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
RTSlib is a Python library that provides an API to the LIO Linux SCSI Target,
and its third-party target fabric modules and backend storage objects.

RTSlib was developed by Datera, Inc. (www.daterainc.com). It is useful for
developing 3rd-party applications, and as a foundation for the Datera
userspace tools.

For more information, please see the targetcli User's Guide at:

http://linux-iscsi.org/wiki/targetcli

and the RTSlib API Reference Guide at:

http://linux-iscsi.org/Doc/rtslib/html
http://linux-iscsi.org/Doc/rtslib/rtslib-API-reference.pdf

%prep
%setup -q -n %{oname}-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1

%build
python setup.py build

%install
%define _vardir /var/target

python setup.py install --prefix=%{_prefix} --root=%{buildroot}

install -vd -m 755 $RPM_BUILD_ROOT%{_vardir}
install -vd -m 755 $RPM_BUILD_ROOT%{_vardir}/pr
install -vd -m 755 $RPM_BUILD_ROOT%{_vardir}/alua
install -vd -m 755 $RPM_BUILD_ROOT%{_vardir}/fabric
install -v -m 644 specs/*.spec $RPM_BUILD_ROOT%{_vardir}/fabric/
install -vd -m 755 $RPM_BUILD_ROOT%{_vardir}/policy
install -v -m 644 policy/*.lio $RPM_BUILD_ROOT%{_vardir}/policy/

%files
%defattr(-,root,root,-)
%doc README.md COPYING
%{python_sitelib}/*
%dir %{_vardir}
%dir %{_vardir}/pr
%dir %{_vardir}/alua
%dir %{_vardir}/fabric
%{_vardir}/fabric/*
%dir %{_vardir}/policy
%{_vardir}/policy/*

%changelog
* Fri Dec 22 2017 lduncan@suse.com
- Fix parsing error with newer pyparsing module (bsc#1058995),
  adding patch:
  * rtslib-fix-parse-error-with-new-pyparsing.patch
* Wed Apr 27 2016 lduncan@suse.com
- Disallow upper-case IQN names (bsc#968745):
  * rtslib-disallow-upper-case-iqn-names.patch
* Tue Apr 19 2016 lduncan@suse.com
- Allow WWNj validation for fc_wwn transport (bsc#975051):
  * rtslib-validate-fc_wwn.patch
- Remove commented out "Source:" line in spec file, for rpmlint
* Thu Feb 11 2016 ohering@suse.de
- Add support for xen-scsiback (fate#315712)
  0001-Add-support-for-xen-scsiback.patch
* Tue Jan 26 2016 lduncan@suse.com
- Add support for nvme discs (bsc#963348), adding:
  * rtslib-add-nvme-support.patch
* Mon Jan 11 2016 lszhu@suse.com
- fix BNC#958274 - Wrong random default name of iSCSI target name
  generated by Targetcli fix iqn wwn name error when include "-"
  patch: rtslib-fix-iqn-wwn.patch
* Thu Dec  3 2015 lduncan@suse.com
- Add qla2xxx_wwn WWN type handling (bsc#954234), adding:
  rtslib-add-qla2xxx_wwn-wwn-type
* Wed Nov 25 2015 ddiss@suse.com
- Fix 64-bit architecture detection; (bnc#956509).
* Fri Sep 25 2015 ddiss@suse.com
- Add explicit Provides for "python-rtslib-rbd", to advertise Ceph RBD
  backstore support; (bnc#947555).
* Wed Sep 23 2015 ddiss@suse.com
- Hardcode Release tag for SES2 release.
* Tue Sep 22 2015 ddiss@suse.com
- Load the RBD backstore kernel module during initialization, if
  available; (bnc#945230).
  + rtslib-load-rbd-mod-on-startup.patch
* Wed Aug 12 2015 ddiss@suse.com
- Add support for the Ceph RBD backend; (fate#318836); (fate#319433).
  + rtslib-fb-rbd-support.patch
* Fri Jul 31 2015 ddiss@suse.com
- Fixed TPG disable logic; (bnc#940216).
  + rtslib-fix_support_for_disabled_tpgs.patch
* Wed Nov 26 2014 lszhu@suse.com
-Bug fix for BNC#907029-configFS mounted problem under root user in SLE12 python-rtslib
* Fri Jul 11 2014 lduncan@suse.com
- Added iblock backstore policy file (bnc#885565), so
  targetcli does not backtrace when creating same, adding
  rtslib-add-iblock-backstore-policy.patch
* Fri Jun 27 2014 lduncan@suse.com
- Added T10 Protection Information attributes (bnc#880355),
  adding one patch and updating spec file to use it:
  rtslib-add-prot-info-attributes.patch
* Wed Jun 25 2014 hare@suse.de
- Do not obsolete lio-utils; it's still required
  by targetcli.
* Thu Jun 19 2014 lduncan@suse.com
- Added patch to set GIT_VERSION string (bnc#880355):
  rtslib-set-git-version-for-sle12.patch
- Updated spec file:
  - use new patch
  - create and populate /var/target tree
  - obsolete lio-utils (to avoid conflicts)
* Mon May 19 2014 hare@suse.de
- Add pyparsing to requires
- README got renamed to README.md
* Fri May 16 2014 hare@suse.de
- Update to latest git commit
  * Update README
  * Minor fixes
  * Add support for nullio ramdisks
  * Update copyright notice
  * Build fixes
  * Add rtslib-git-update.patch
* Wed Dec 18 2013 hare@suse.de
- Update to version 2.2 from github repository:
  * targetcli moved into separate package
  * Removed references to targetcli program and manpages
- Update description
- Change license tag to correct one; rtslib is licensed under Apache-2.0
- Add missing dependencies to get it fully working
* Sun Nov 24 2013 p.drouand@gmail.com
- Change tarball download location to new official one
- Update to version 2.1.fb42
  + No changelog available
- Remove rtslib-qla2xxx-fix.patch; merged on upstream release
- Add man pages for targetcli
* Wed Oct 16 2013 hare@suse.de
- Fixup typo in fabric.py (bnc#837519)
* Wed Feb 27 2013 saschpe@suse.de
- Replace this with the official version from PyPI and redo the spec file:
  + Drop useless (build) requires
  + Drop even more useless doc sub-package
  + Drop patches that are upstream
* Fri Jan 18 2013 hare@suse.de
- Fix debian copyright file to refer to correct license
* Thu Jan 17 2013 hare@suse.de
- Initial commit from git repository
